@@ -1,7 +1,7 @@
 package App::xsum;
 
-our $DATE = '2019-08-21'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2019-09-12'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -14,7 +14,7 @@ $SPEC{xsum} = {
     summary => 'Compute and check file checksums/digests (using various algorithms)',
     description => <<'_',
 
-`xsum` is a small handy utility that can be used as an alternative/replacement
+`xsum` is a handy small utility that can be used as an alternative/replacement
 for the individual per-algorithm Unix utilities like `md5sum`, `sha1sum`,
 `sha224sum`, and so on. It's basically the same as said Unix utilities but you
 can use a single command instead.
@@ -41,7 +41,14 @@ _
             schema => ['array*', of=>'filename*'],
             req => 1,
             pos => 0,
-            greedy => 1,
+            slurpy => 1,
+        },
+        checksums => {
+            'x.name.is_plural' => 1,
+            'x.name.singular' => 'file',
+            summary => 'Supply checksum(s)',
+            schema => ['array*', of=>'str*'],
+            cmdline_aliases => {C=>{}},
         },
         algorithm => {
             schema => ['str*', in=>[qw/crc32 md5 sha1 sha224 sha256 sha384 sha512 sha512224 sha512256/]],
@@ -89,6 +96,20 @@ _
             test => 0,
             'x.doc.show_result' => 0,
         },
+        {
+            summary => 'Check MD5 digest of one file',
+            src => 'xsum -a md5 download.exe -C 9f4b2277f50a412e56de6e0306f4afb8',
+            src_plang => 'bash',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+        {
+            summary => 'Check MD5 digest of two files',
+            src => 'xsum -a md5 download1.exe -C 9f4b2277f50a412e56de6e0306f4afb8 download2.zip -C 62b3bf86abdfdd87e9f6a3ea7b51aa7b',
+            src_plang => 'bash',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
     ],
     'cmdline.skip_format' => 1,
 };
@@ -100,8 +121,13 @@ sub xsum {
 
     my $num_success;
     my $envres;
+    my $i = -1;
     for my $file (@{ $args{files} }) {
+        $i++;
         if ($args{check}) {
+
+            # treat file as checksums file. extract filenames and checksums from
+            # the checksums file and check them.
             my $res = Parse::Sums::parse_sums(filename => $file);
             unless ($res->[0] == 200) {
                 $envres //= [
@@ -135,7 +161,35 @@ sub xsum {
                     print "$entry->{file}: FAILED\n";
                 }
             }
+
+        } elsif ($args{checksums} && @{ $args{checksums} }) {
+
+            # check checksum of file against checksum provided in 'checksums'
+            # argument.
+            if ($#{ $args{checksums} } < $i) {
+                warn "No checksum value provided for file '$file', please specify with -C\n";
+                next;
+            }
+            my $digest_res = File::Digest::digest_file(
+                file => $file, algorithm => $args{algorithm});
+            unless ($digest_res) {
+                $envres //= [
+                    500, "Some files' checksums cannot be checked"];
+                warn "$file: Cannot compute digest: $digest_res->[1]\n";
+                next;
+            }
+            if ($digest_res->[2] eq $args{checksums}[$i]) {
+                print "$file: OK\n";
+                $num_success++;
+            } else {
+                $envres //= [
+                    500, "Some files did NOT match computed checksums"];
+                print "$file: FAILED\n";
+            }
+
         } else {
+
+            # produce checksum for file
             my $res = File::Digest::digest_file(
                 file => $file, algorithm => $args{algorithm});
             unless ($res->[0] == 200) {
@@ -148,6 +202,7 @@ sub xsum {
             } else {
                 printf "%s  %s\n", $res->[2], $file;
             }
+
         }
     }
 
@@ -170,7 +225,7 @@ App::xsum - Compute and check file checksums/digests (using various algorithms)
 
 =head1 VERSION
 
-This document describes version 0.002 of App::xsum (from Perl distribution App-xsum), released on 2019-08-21.
+This document describes version 0.003 of App::xsum (from Perl distribution App-xsum), released on 2019-09-12.
 
 =head1 SYNOPSIS
 
@@ -187,7 +242,7 @@ Usage:
 
 Compute and check file checksums/digests (using various algorithms).
 
-C<xsum> is a small handy utility that can be used as an alternative/replacement
+C<xsum> is a handy small utility that can be used as an alternative/replacement
 for the individual per-algorithm Unix utilities like C<md5sum>, C<sha1sum>,
 C<sha224sum>, and so on. It's basically the same as said Unix utilities but you
 can use a single command instead.
@@ -209,6 +264,10 @@ Arguments ('*' denotes required arguments):
 
 Read checksum from files and check them.
 
+=item * B<checksums> => I<array[str]>
+
+Supply checksum(s).
+
 =item * B<files>* => I<array[filename]>
 
 =item * B<tag> => I<bool>
